BEGIN TRANSACTION;
CREATE TABLE fourcc
(
  fourcc char(4) NOT NULL,
  "owner" varchar(100),
  registered date,
  description varchar(200) NOT NULL,
  CONSTRAINT fourcc_pkey PRIMARY KEY (fourcc)
);
INSERT INTO "fourcc" VALUES('2VUY',NULL,NULL,'Optibase VideoPump 8-bit 4:2:2 Component Y''CbCr');
INSERT INTO "fourcc" VALUES('1978',NULL,NULL,'A.M.Paredes predictor (LossLess)');
INSERT INTO "fourcc" VALUES('3IV0',NULL,NULL,'MPEG4-based codec 3ivx');
INSERT INTO "fourcc" VALUES('3IV1','3ivx',NULL,'3ivx (MPEG4-based)');
INSERT INTO "fourcc" VALUES('3IV2','3ivx',NULL,'3ivx (MPEG4-based)');
INSERT INTO "fourcc" VALUES('3IVD','3ivx',NULL,'3ivx DivX Doctored');
INSERT INTO "fourcc" VALUES('3IVX','3ivx',NULL,'3ivx (MPEG4-based)');
INSERT INTO "fourcc" VALUES('3VID','3ivx',NULL,'3ivx (MPEG4-based)');
INSERT INTO "fourcc" VALUES('8BPS','Apple',NULL,'Planar RGB w/alpha');
INSERT INTO "fourcc" VALUES('____','NA',NULL,'|No Codec');
INSERT INTO "fourcc" VALUES('_BIT','* No codec needed',NULL,'BI_BITFIELDS (Raw RGB)');
INSERT INTO "fourcc" VALUES('_JPG','Joint Photo Experts Group',NULL,'BI_JPEG JPEG compressed');
INSERT INTO "fourcc" VALUES('_PNG','W3C/ISO/IEC (RFC-2083)',NULL,'BI_PNG PNG compressed');
INSERT INTO "fourcc" VALUES('_RAW','N.A.',NULL,'Full Frames (Uncompressed)');
INSERT INTO "fourcc" VALUES('_RGB','* No codec needed',NULL,'BI_RGB Raw Bitmap');
INSERT INTO "fourcc" VALUES('_RL4','* No codec needed',NULL,'BI_RLE4 (RLE 4bpp RGB)');
INSERT INTO "fourcc" VALUES('_RL8','* No codec needed',NULL,'BI_RLE8 (RLE 8bpp RGB)');
INSERT INTO "fourcc" VALUES('AAS4','Autodesk',NULL,'Autodesk Animator codec (RLE)');
INSERT INTO "fourcc" VALUES('AASC','Autodesk',NULL,'Autodesk Animator codec');
INSERT INTO "fourcc" VALUES('ABYR','Kensington',NULL,'Kensington ?');
INSERT INTO "fourcc" VALUES('ACTL',NULL,NULL,'Streambox ACT-L2');
INSERT INTO "fourcc" VALUES('ADV1',NULL,NULL,'Loronix WaveCodec (used in various CCTV products)');
INSERT INTO "fourcc" VALUES('ADVJ','Avid Technology, Inc',NULL,'Avid M-JPEG Avid Technology Also known as AVRn');
INSERT INTO "fourcc" VALUES('AEIK',NULL,NULL,'Intel Indeo Video 3.2 (Vector Quantization)');
INSERT INTO "fourcc" VALUES('NYUV','Nogatech Ltd.','1999-06-28','Nogatech YUV 422 format.');
INSERT INTO "fourcc" VALUES('AFLC','Autodesk',NULL,'Autodesk Animator codec');
INSERT INTO "fourcc" VALUES('AFLI','Autodesk',NULL,'Autodesk Animator codec');
INSERT INTO "fourcc" VALUES('AHDV',NULL,NULL,'CineForm 10-bit Visually Perfect HD (Wavelet)');
INSERT INTO "fourcc" VALUES('AJPG',NULL,NULL,'22fps JPEG-based codec for digital cameras');
INSERT INTO "fourcc" VALUES('ALAC','Apple',NULL,'Apple lossless audio');
INSERT INTO "fourcc" VALUES('PCLE','Pinnacle / Avid','1998-03-30','Studio 400 video codec.');
INSERT INTO "fourcc" VALUES('QPEG','Q-Team Dr Knabe','1996-11-15','QPEG 1.1');
INSERT INTO "fourcc" VALUES('AMR ','3GPP.org',NULL,'AMR Speech Codec');
INSERT INTO "fourcc" VALUES('RGBT','* No codec needed','1994-10-21','Raw RGB w/ Transparency');
INSERT INTO "fourcc" VALUES('RIVA','NVIDIA Corporation','1999-03-22','Swizzled texture format.');
INSERT INTO "fourcc" VALUES('AP42','AngelPotion',NULL,'AngelPotion Definitive (hack MS MP43)');
INSERT INTO "fourcc" VALUES('ASLC',NULL,NULL,'AlparySoft Lossless Codec');
INSERT INTO "fourcc" VALUES('ASV1','Asus',NULL,'Asus Video');
INSERT INTO "fourcc" VALUES('ASV2','Asus',NULL,'Asus Video (2)');
INSERT INTO "fourcc" VALUES('ASVX','Asus',NULL,'Asus Video 2.0');
INSERT INTO "fourcc" VALUES('ATM4',NULL,NULL,'Ahead Nero Digital MPEG-4 Codec');
INSERT INTO "fourcc" VALUES('RLND','Roland Corporation','2002-03-15','Not specified.');
INSERT INTO "fourcc" VALUES('RT21','Ligos / Indeo / Intel','1993-08-01','Indeo 2.1');
INSERT INTO "fourcc" VALUES('RVX ','Intel Corporation','1996-06-12','Intel RDX');
INSERT INTO "fourcc" VALUES('AV1X','Avid Technology, Inc',NULL,'Avid 1:1x (Quick Time)');
INSERT INTO "fourcc" VALUES('AVC1','ITU-T/ISO/IEC',NULL,'H.264/MPEG-4 AVC');
INSERT INTO "fourcc" VALUES('AVD1','Avid Technology, Inc',NULL,'Avid DV (Quick Time)');
INSERT INTO "fourcc" VALUES('AVDJ',NULL,NULL,'Independent JPEG Group''s codec');
INSERT INTO "fourcc" VALUES('AVDN','Avid Technology, Inc',NULL,'Avid DNxHD (Quick Time)');
INSERT INTO "fourcc" VALUES('AVDV','Avid Technology, Inc',NULL,'Avid DV');
INSERT INTO "fourcc" VALUES('AVI1',NULL,NULL,'MainConcept Motion JPEG Codec');
INSERT INTO "fourcc" VALUES('AVI2',NULL,NULL,'MainConcept Motion JPEG Codec');
INSERT INTO "fourcc" VALUES('AVID','Avid Technology, Inc',NULL,'Avid Motion JPEG');
INSERT INTO "fourcc" VALUES('AVIS',NULL,NULL,'Wrapper for AviSynth (Dummy codec)');
INSERT INTO "fourcc" VALUES('AVMP','Avid Technology, Inc',NULL,'Avid IMX (Quick Time)');
INSERT INTO "fourcc" VALUES('AVR ','Avid Technology, Inc',NULL,'Avid ABVB/NuVista MJPEG w/alpha');
INSERT INTO "fourcc" VALUES('AVRN',NULL,NULL,'Independent JPEG Group''s codec');
INSERT INTO "fourcc" VALUES('AVUI','Avid Technology, Inc',NULL,'Avid Meridien Uncompressed w/alpha');
INSERT INTO "fourcc" VALUES('AVUP','Avid Technology, Inc',NULL,'Avid 10bit Packed (Quick Time)');
INSERT INTO "fourcc" VALUES('AYUV','*No codec needed',NULL,'4:4:4 YUV format');
INSERT INTO "fourcc" VALUES('AZPR','Apple',NULL,'Apple QuickTime');
INSERT INTO "fourcc" VALUES('AZRP','Apple',NULL,'Apple QuickTime');
INSERT INTO "fourcc" VALUES('BGR ','* No codec needed',NULL,'Raw RGB32');
INSERT INTO "fourcc" VALUES('BHIV',NULL,NULL,'BeHere iVideo');
INSERT INTO "fourcc" VALUES('BINK','RAD Game Tools',NULL,'Bink Video');
INSERT INTO "fourcc" VALUES('BIT ',NULL,NULL,'BI_BITFIELDS (Raw RGB)');
INSERT INTO "fourcc" VALUES('BITM','Microsoft',NULL,'Microsoft H.261');
INSERT INTO "fourcc" VALUES('BLOX',NULL,NULL,'Jan Jezabek BLOX MPEG Codec');
INSERT INTO "fourcc" VALUES('BLZ0','Blizzard Entertainment',NULL,'MPEG-4 (DivX compatible)');
INSERT INTO "fourcc" VALUES('S263','~ISOMP4','1998-06-25','ITU H.263 video (3GPP)');
INSERT INTO "fourcc" VALUES('SCCD','Luminositi, Inc.','1998-05-11','Luminositi SoftCam codec.');
INSERT INTO "fourcc" VALUES('BTVC','Conexant',NULL,'Conexant Composite Video');
INSERT INTO "fourcc" VALUES('BW00',NULL,NULL,'BergWave (Wavelet)');
INSERT INTO "fourcc" VALUES('BW10','Data Translation',NULL,'Broadway MPEG Capture/Compression');
INSERT INTO "fourcc" VALUES('BXBG',NULL,NULL,'BOXX BGR');
INSERT INTO "fourcc" VALUES('BXRG',NULL,NULL,'BOXX RGB');
INSERT INTO "fourcc" VALUES('BXY2',NULL,NULL,'BOXX 10-bit YUV');
INSERT INTO "fourcc" VALUES('BXYV',NULL,NULL,'BOXX YUV');
INSERT INTO "fourcc" VALUES('SDCC','Sun Communications','1997-09-15','Digital Camera Codec');
INSERT INTO "fourcc" VALUES('CDV5',NULL,NULL,'Canopus SD50/DVHD');
INSERT INTO "fourcc" VALUES('SFMC','CrystalNet','1996-07-25','Surface Fitting Method');
INSERT INTO "fourcc" VALUES('CDVH',NULL,NULL,'Canopus SD50/DVHD');
INSERT INTO "fourcc" VALUES('CFCC','Digital Processing Systems',NULL,'DPS Perception');
INSERT INTO "fourcc" VALUES('CFHD',NULL,NULL,'CineForm 10-bit Visually Perfect HD (Wavelet)');
INSERT INTO "fourcc" VALUES('SMSC','Radius','1994-11-15','Proprietary codec');
INSERT INTO "fourcc" VALUES('SMSD','Radius','1994-11-15','Proprietary codec');
INSERT INTO "fourcc" VALUES('CJPG','Creative Labs',NULL,'WebCam JPEG');
INSERT INTO "fourcc" VALUES('CLJR','Cirrus',NULL,'Cirrus Logic YUV 4:1:1');
INSERT INTO "fourcc" VALUES('CLLC',NULL,NULL,'Canopus LossLess');
INSERT INTO "fourcc" VALUES('CLPL',NULL,NULL,'Format similar to YV12 but including a level of indirection.');
INSERT INTO "fourcc" VALUES('SPLC','http://splashstudios.net/','1996-01-08','Splash Studios ACM Audio Codec');
INSERT INTO "fourcc" VALUES('CMYK','Colorgraph (UK)',NULL,'Common Data Format in Printing');
INSERT INTO "fourcc" VALUES('COL0',NULL,NULL,'FFmpeg DivX ;-) (MS MPEG-4 v3)');
INSERT INTO "fourcc" VALUES('COL1',NULL,NULL,'FFmpeg DivX ;-) (MS MPEG-4 v3)');
INSERT INTO "fourcc" VALUES('SQZ2','Microsoft','1997-09-16','VXTreme Video Codec V2');
INSERT INTO "fourcc" VALUES('CRAM','Microsoft',NULL,'Microsoft Video 1');
INSERT INTO "fourcc" VALUES('CSCD',NULL,NULL,'RenderSoft CamStudio lossless Codec (LZO & GZIP compression)');
INSERT INTO "fourcc" VALUES('STVA','ST Microelectronics','1999-08-09','ST CMOS Imager Data (Bayer)');
INSERT INTO "fourcc" VALUES('CTRX',NULL,NULL,'Citrix Scalable Video Codec');
INSERT INTO "fourcc" VALUES('CUVC',NULL,NULL,'Canopus HQ');
INSERT INTO "fourcc" VALUES('STVB','ST Microelectronics','1999-08-09','ST CMOS Imager Data (Nudged Bayer)');
INSERT INTO "fourcc" VALUES('STVC','ST Microelectronics','1999-08-09','ST CMOS Imager Data (Bunched)');
INSERT INTO "fourcc" VALUES('CYUV','Creative Labs, Inc.',NULL,'Creative Labs YUV');
INSERT INTO "fourcc" VALUES('CYUY','ATI Technologies',NULL,'ATI Proprietary YUV compression');
INSERT INTO "fourcc" VALUES('D261','ITU-T',NULL,'H.261');
INSERT INTO "fourcc" VALUES('D263','ITU-T',NULL,'H.263');
INSERT INTO "fourcc" VALUES('DAVC',NULL,NULL,'Dicas MPEGable H.264/MPEG-4 AVC base profile codec');
INSERT INTO "fourcc" VALUES('DC25',NULL,NULL,'MainConcept ProDV Codec');
INSERT INTO "fourcc" VALUES('DCAP',NULL,NULL,'Pinnacle DV25 Codec');
INSERT INTO "fourcc" VALUES('DCL1',NULL,NULL,'Data Connection Conferencing Codec');
INSERT INTO "fourcc" VALUES('DCT0',NULL,NULL,'WniWni Codec');
INSERT INTO "fourcc" VALUES('DFSC',NULL,NULL,'DebugMode FrameServer VFW Codec');
INSERT INTO "fourcc" VALUES('DIB ','* No codec needed',NULL,'Device Independent Bitmap');
INSERT INTO "fourcc" VALUES('DIV1','Microsoft',NULL,'Microsoft MPEG-4 v1');
INSERT INTO "fourcc" VALUES('DIV2','Microsoft',NULL,'Microsoft MPEG-4 v2');
INSERT INTO "fourcc" VALUES('SV10','Sorenson Media','1997-09-15','Video R1');
INSERT INTO "fourcc" VALUES('DIV5','divx.com',NULL,'DivX 5.x/6.x');
INSERT INTO "fourcc" VALUES('DIV6',NULL,NULL,'DivX ;-) (MS MPEG-4 v3)');
INSERT INTO "fourcc" VALUES('DM4V',NULL,NULL,'Dicas MPEGable MPEG-4');
INSERT INTO "fourcc" VALUES('DMB1','Matrox',NULL,'Matrox MJPG for RainbowRunner');
INSERT INTO "fourcc" VALUES('DMB2','Matrox',NULL,'Matrox MJPG for RainbowRunner');
INSERT INTO "fourcc" VALUES('DMK2',NULL,NULL,'ViewSonic V36 PDA Video');
INSERT INTO "fourcc" VALUES('DP02',NULL,NULL,'DynaPel MPEG-4');
INSERT INTO "fourcc" VALUES('SV3M','Sorenson Vision, Inc.','1999-06-01','Sorenson SV3 module decoder.');
INSERT INTO "fourcc" VALUES('TLMS','TeraLogic','1997-09-16','Motion Intraframe Codec');
INSERT INTO "fourcc" VALUES('TLST','TeraLogic','1997-09-16','Motion Intraframe Codec');
INSERT INTO "fourcc" VALUES('TM20','Duck (now ON2) Corp','1997-09-16','TrueMotion 2.0');
INSERT INTO "fourcc" VALUES('TMIC','TeraLogic','1997-09-16','Motion Intraframe Codec');
INSERT INTO "fourcc" VALUES('TMOT','Horizons Technology','1994-10-21','TrueMotion S');
INSERT INTO "fourcc" VALUES('TR20','Duck Corporation','1997-09-16','TrueMotion RT 2.0');
INSERT INTO "fourcc" VALUES('DPS0','DPS/Leitch',NULL,'DPS Reality Motion JPEG');
INSERT INTO "fourcc" VALUES('DPSC','DPS/Leitch',NULL,'DPS PAR Motion JPEG');
INSERT INTO "fourcc" VALUES('DRMI','Apple',NULL,'iPod DRM Protected');
INSERT INTO "fourcc" VALUES('DRWX',NULL,NULL,'Pinnacle DV25 Codec');
INSERT INTO "fourcc" VALUES('DSVD',NULL,NULL,'DV Codec');
INSERT INTO "fourcc" VALUES('DTMT',NULL,NULL,'Media-100 Codec');
INSERT INTO "fourcc" VALUES('DTNT',NULL,NULL,'Media-100 Codec');
INSERT INTO "fourcc" VALUES('UYVP','Evans & Sutherland','2000-11-15','YCbCr 4:2:2 extended precision');
INSERT INTO "fourcc" VALUES('DV10',NULL,NULL,'BlueFish444 (lossless RGBA, YUV 10-bit)');
INSERT INTO "fourcc" VALUES('DV25','Matrox',NULL,'Matrox DVCPRO codec');
INSERT INTO "fourcc" VALUES('DV50','Matrox',NULL,'Matrox DVCPRO50 codec');
INSERT INTO "fourcc" VALUES('DVAN','Pinnacle / Avid',NULL,'Pinnacle miroVideo DV300 SW codec');
INSERT INTO "fourcc" VALUES('DVC ','IEC 61834 and SMPTE 314M',NULL,'DVC/DV Video');
INSERT INTO "fourcc" VALUES('DVCP','IEC 61834 and SMPTE 314M',NULL,'DVC/DV Video');
INSERT INTO "fourcc" VALUES('DVCS',NULL,NULL,'MainConcept DV Codec');
INSERT INTO "fourcc" VALUES('V422','Vitec Multimedia','1993-12-13','24-bit YUV 4:2:2');
INSERT INTO "fourcc" VALUES('V655','Vitec Multimedia','1993-12-13','16-bit YUV 4:2:2');
INSERT INTO "fourcc" VALUES('DVHD','IEC Standard',NULL,'DV 1125 lines at 30.00 Hz or 1250 lines at 25.00 Hz');
INSERT INTO "fourcc" VALUES('DVIS',NULL,NULL,'VSYNC DualMoon Iris DV codec');
INSERT INTO "fourcc" VALUES('DVL ','Radius / Cinepak',NULL,'Radius SoftDV 16:9 NTSC');
INSERT INTO "fourcc" VALUES('DVLP','Radius / Cinepak',NULL,'Radius SoftDV 16:9 PAL');
INSERT INTO "fourcc" VALUES('DVMA','Darim Vision Co., Ltd.',NULL,'Darim Vision DVMPEG (dummy for MPEG compressor)');
INSERT INTO "fourcc" VALUES('VCR1','ATI Technologies','1997-10-23','ATI Video Codec 1');
INSERT INTO "fourcc" VALUES('DVOR',NULL,NULL,'BlueFish444 (lossless RGBA, YUV 10-bit)');
INSERT INTO "fourcc" VALUES('DVPN','Apple',NULL,'Apple QT DV (NTSC)');
INSERT INTO "fourcc" VALUES('DVPP','Apple',NULL,'Apple QT DV (PAL)');
INSERT INTO "fourcc" VALUES('DVR1',NULL,NULL,'TARGA2000 Codec');
INSERT INTO "fourcc" VALUES('DVRS',NULL,NULL,'VSYNC DualMoon Iris DV codec');
INSERT INTO "fourcc" VALUES('DVSD','IEC 61834 and SMPTE 314M',NULL,'DVC/DV Video');
INSERT INTO "fourcc" VALUES('DVSL','IEC Standard',NULL,'DV compressed in SD (SDL)');
INSERT INTO "fourcc" VALUES('VCR2','ATI Technologies','1997-10-23','ATI Video Codec 2');
INSERT INTO "fourcc" VALUES('VCR3','ATI Technologies','1997-10-23','ATI VCR 3.0');
INSERT INTO "fourcc" VALUES('VCR4','ATI Technologies','1997-10-23','ATI VCR 4.0');
INSERT INTO "fourcc" VALUES('DX50','divx.com',NULL,'DivX 5.x/6.x');
INSERT INTO "fourcc" VALUES('DXGM',NULL,NULL,'Electronic Arts Game Video codec');
INSERT INTO "fourcc" VALUES('DXRE','DivX',NULL,'DivX Subtitle Codec');
INSERT INTO "fourcc" VALUES('DXSB','DivX',NULL,'DivX Subtitle Codec');
INSERT INTO "fourcc" VALUES('VCR5','ATI Technologies','1997-10-23','ATI VCR 5.0');
INSERT INTO "fourcc" VALUES('VCR6','ATI Technologies','1997-10-23','ATI VCR 6.0');
INSERT INTO "fourcc" VALUES('VCR7','ATI Technologies','1997-10-23','ATI VCR 7.0');
INSERT INTO "fourcc" VALUES('VCR8','ATI Technologies','1997-10-23','ATI VCR 8.0');
INSERT INTO "fourcc" VALUES('VCR9','ATI Technologies','1997-10-23','ATI VCR 9.0');
INSERT INTO "fourcc" VALUES('VCWV','VideoCon','2000-06-06','VideoCon wavelet.');
INSERT INTO "fourcc" VALUES('VGPX','Alaris','1998-03-30','VGPixel Codec');
INSERT INTO "fourcc" VALUES('VIVO','Vivo Software','1997-09-16','Vivo H.263');
INSERT INTO "fourcc" VALUES('VIXL','Miro (now part of Pinnacle Systems)','1994-07-24','Video XL');
INSERT INTO "fourcc" VALUES('VJPG','Video Communication Systems','2001-02-05','A JPEG-based compression scheme for RGB bitmaps.');
INSERT INTO "fourcc" VALUES('VLV1','VideoLogic (now PURE Digital)','1993-06-08','Videologic codec');
INSERT INTO "fourcc" VALUES('VQC1','http://eprints.ecs.soton.ac.uk/archive/00001310/01/VTC97-js.pdf','1998-11-13','Vector-quantised codec 1 (high compression)');
INSERT INTO "fourcc" VALUES('VQC2','http://eprints.ecs.soton.ac.uk/archive/00001310/01/VTC97-js.pdf','1998-11-13','Vector-quantised codec 2 (research)');
INSERT INTO "fourcc" VALUES('VQJP','ViewQuest Technologies Inc.','2000-11-28','VQ630 dual-mode digital camera.');
INSERT INTO "fourcc" VALUES('VQS4','ViewQuest Technologies Inc.','2000-11-28','VQ110 digital video camera.');
INSERT INTO "fourcc" VALUES('VTC1','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC2','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC3','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC4','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC5','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC6','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC7','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC8','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VTC9','NVIDIA Corporation','2000-10-12','Not specified.');
INSERT INTO "fourcc" VALUES('VX1K','Lucent','1999-02-17','VX1000S Video Codec');
INSERT INTO "fourcc" VALUES('VX2K','Lucent','1999-02-17','VX2000S Video Codec');
INSERT INTO "fourcc" VALUES('VXSP','Lucent','1999-02-17','VX1000SP Video Codec');
INSERT INTO "fourcc" VALUES('WBVC','Winbond Electronics','1997-09-17','W9960');
INSERT INTO "fourcc" VALUES('WINX','Winnov','2000-05-11','Winnov Software Compression');
INSERT INTO "fourcc" VALUES('WJPG','Winbond','1999-03-04','Winbond JPEG?');
INSERT INTO "fourcc" VALUES('WMS2','Microsoft','2001-04-02','Reserved.');
INSERT INTO "fourcc" VALUES('WMV1','Microsoft','2001-04-02','WMP v7');
INSERT INTO "fourcc" VALUES('WMV2','Microsoft','2001-04-02','WMP v8');
INSERT INTO "fourcc" VALUES('WMV3','Microsoft','2001-04-02','WMP v9 (VC-1 Simple/Main)');
INSERT INTO "fourcc" VALUES('WNV1','Winnov','2000-05-11','Winnov Hardware Compression');
INSERT INTO "fourcc" VALUES('WPY2','Winnov, Inc.','2000-05-11','Not specified.');
INSERT INTO "fourcc" VALUES('EKQ0','http://www.elsa.com/',NULL,'related to Elsa Graphics cards');
INSERT INTO "fourcc" VALUES('ELK0','http://www.elsa.com/',NULL,'related to Elsa Graphics cards');
INSERT INTO "fourcc" VALUES('EM2V','http://www.etymonix.com/',NULL,'Etymonix MPEG-2 I-frame');
INSERT INTO "fourcc" VALUES('WZCD','CORE Co. Ltd.','2000-06-20','iScan.');
INSERT INTO "fourcc" VALUES('ENCA','~ISOMP4',NULL,'ISMA Encrypted/Protected audio');
INSERT INTO "fourcc" VALUES('ENCV','~ISOMP4',NULL,'ISMA Encrypted/Protected video');
INSERT INTO "fourcc" VALUES('EQK0',NULL,NULL,'Elsa graphics card quick codec');
INSERT INTO "fourcc" VALUES('ESCP','Eidos Technologies',NULL,'Escape');
INSERT INTO "fourcc" VALUES('WZDC','CORE Co. Ltd.','2000-06-20','iSnap.');
INSERT INTO "fourcc" VALUES('FFDS','FFmpeg',NULL,'ffds Lossless Video');
INSERT INTO "fourcc" VALUES('FFV1','FFmpeg',NULL,'ffds Lossless Video');
INSERT INTO "fourcc" VALUES('FFVH','ffmpeg',NULL,'FFmpeg Lossless HuffYUV (open source)');
INSERT INTO "fourcc" VALUES('FLIC','http://www.autodesk.com',NULL,'Autodesk FLI/FLC Animation');
INSERT INTO "fourcc" VALUES('FLV1','Sorenson Media',NULL,'Flash Sorenson Video');
INSERT INTO "fourcc" VALUES('FLV4','On2 Technologies',NULL,'Flash VP6');
INSERT INTO "fourcc" VALUES('FMJP',NULL,NULL,'D-Vision fieldbased ISO MJPEG');
INSERT INTO "fourcc" VALUES('FMP4','FFmpeg/ffdshow (open source)',NULL,'FFmpeg/ffdshow ISO MPEG-4');
INSERT INTO "fourcc" VALUES('FPS1','beepa',NULL,'FRAPS Codec');
INSERT INTO "fourcc" VALUES('FRLE',NULL,NULL,'SoftLab-NSK Y16 + Alpha RLE');
INSERT INTO "fourcc" VALUES('FRWU','Darim Vision Co., Ltd.',NULL,'Darim Vision Forward Uncompressed');
INSERT INTO "fourcc" VALUES('FSV1','ffmpeg (open source)',NULL,'FFmpeg Flash Screen video');
INSERT INTO "fourcc" VALUES('FVFW',NULL,NULL,'ff MPEG-4 based on XviD codec');
INSERT INTO "fourcc" VALUES('G2M2','Citrix Systems, Inc.',NULL,'GoToMeeting/GoToWebinar Codec v2.x');
INSERT INTO "fourcc" VALUES('G2M3','Citrix Systems, Inc.',NULL,'GoToMeeting/GoToWebinar Codec v3.x');
INSERT INTO "fourcc" VALUES('G726','~ISOMP4',NULL,'ITU-T Recommendation G.726 (1990)');
INSERT INTO "fourcc" VALUES('GEPJ','White Pine (ex Paradigm Matrix)',NULL,'Motion JPEG Codec');
INSERT INTO "fourcc" VALUES('GJPG',NULL,NULL,'Grand Tech GT891x Codec');
INSERT INTO "fourcc" VALUES('GLCC',NULL,NULL,'GigaLink AV Capture codec');
INSERT INTO "fourcc" VALUES('GLZW','gabest@freemail.hu',NULL,'Motion LZW');
INSERT INTO "fourcc" VALUES('GPEG','gabest@freemail.hu',NULL,'Motion JPEG');
INSERT INTO "fourcc" VALUES('GPJM',NULL,NULL,'Pinnacle ReelTime MJPEG Codec');
INSERT INTO "fourcc" VALUES('GREY',NULL,NULL,'Apparently a duplicate of Y800');
INSERT INTO "fourcc" VALUES('XJPG','Xirlink, Inc.','2001-02-14','Xirlink JPEG-like compressor.');
INSERT INTO "fourcc" VALUES('GXVE','SoftMedia',NULL,'SoftMedia ViVD V2');
INSERT INTO "fourcc" VALUES('XLV0','NetXL Inc.','1997-09-18','XL Video Decoder');
INSERT INTO "fourcc" VALUES('XWV0',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV1',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV2',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV3',NULL,'2000-07-26','XiWave Video Codec (Xi-3 Video)');
INSERT INTO "fourcc" VALUES('XWV4',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV5',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV6',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV7',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('XWV8',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('HD10',NULL,NULL,'BlueFish444 (lossless RGBA, YUV 10-bit)');
INSERT INTO "fourcc" VALUES('HDX4','JOMIGO GmbH.',NULL,'HDX4 MPEG-4 Codec');
INSERT INTO "fourcc" VALUES('HFYU','Open Source',NULL,'Huffyuv Lossless Codec');
INSERT INTO "fourcc" VALUES('HM12','Hauppauge',NULL,'Hauppauge PVR 250/350 MB-YUV Format');
INSERT INTO "fourcc" VALUES('HMCR','Rendition',NULL,'Rendition Motion Compensation Format');
INSERT INTO "fourcc" VALUES('HMRR','Rendition',NULL,'Rendition Motion Compensation Format');
INSERT INTO "fourcc" VALUES('XWV9',NULL,'2000-07-26','XiWave Video Codec');
INSERT INTO "fourcc" VALUES('YC12','Intel','1996-06-12','YUV 12 codec');
INSERT INTO "fourcc" VALUES('YCCK','B.U.G., Inc.','2000-11-10','Uncompressed YCbCr video with key data.');
INSERT INTO "fourcc" VALUES('YUV8','Winnov, Inc.','1993-09-05','MM_WINNOV_CAVIAR_YUV8');
INSERT INTO "fourcc" VALUES('IDM0',NULL,NULL,'IDM Motion Wavelets 2.0');
INSERT INTO "fourcc" VALUES('IF09','*No codec needed',NULL,'Indeo YVU9 (YVU9 with additional delta-frame info after the U plane)');
INSERT INTO "fourcc" VALUES('IFO9','Intel Corporation',NULL,'Intel intermediate YUV9.');
INSERT INTO "fourcc" VALUES('IGOR',NULL,NULL,'Power DVD');
INSERT INTO "fourcc" VALUES('IJPG','Intergraph',NULL,'Intergraph JPEG');
INSERT INTO "fourcc" VALUES('YUV9','Intel Corporation','1993-08-01','YUV9');
INSERT INTO "fourcc" VALUES('YUYP','Evans & Sutherland','2000-11-15','YCbCr 4:2:2 extended precision, 10 bits per component (Y0U0Y1V0).');
INSERT INTO "fourcc" VALUES('YUYV','Canopus, Co., Ltd.','1993-06-08','BI_YUYV, Canopus');
INSERT INTO "fourcc" VALUES('IMC1',NULL,NULL,'As YV12, except the U and V planes have same stride as the Y plane');
INSERT INTO "fourcc" VALUES('IMC2',NULL,NULL,'Similar to IMC1, w/ U and V lines interleaved at half stride boundaries');
INSERT INTO "fourcc" VALUES('IMC3',NULL,NULL,'As IMC1, except that U and V are swapped');
INSERT INTO "fourcc" VALUES('IMC4',NULL,NULL,'As IMC2, except that U and V are swapped');
INSERT INTO "fourcc" VALUES('IMG ','Apple',NULL,'Apple RGB');
INSERT INTO "fourcc" VALUES('IMJG',NULL,NULL,'Accom SphereOUS MJPEG with Alpha-channel');
INSERT INTO "fourcc" VALUES('ZPEG','Metheus','1993-08-24','Video Zipper');
INSERT INTO "fourcc" VALUES('IPJ2',NULL,NULL,'Image Power JPEG2000');
INSERT INTO "fourcc" VALUES('IR21','Ligos / Indeo / Intel',NULL,'Indeo 2.1');
INSERT INTO "fourcc" VALUES('ZPG1','VoDeo Solutions, Inc.','2002-04-13','Not specified.');
INSERT INTO "fourcc" VALUES('ZPG2','VoDeo Solutions, Inc.','2002-04-15','Not specified.');
INSERT INTO "fourcc" VALUES('ZPG3','VoDeo Solutions, Inc.','2002-04-15','Not specified.');
INSERT INTO "fourcc" VALUES('ZPG4','VoDeo Solutions, Inc.','2002-04-15','Not specified.');
INSERT INTO "fourcc" VALUES('FRWD','SoftLab-Nsk','1998-06-25','Forward Motion JPEG');
INSERT INTO "fourcc" VALUES('FRWT','Darim Vision Co., Ltd.','1998-06-25','Darim Vision Forward Motion JPEG');
INSERT INTO "fourcc" VALUES('FVF1','Iterated Systems, Inc.','1993-08-24','Fractal Video Frame');
INSERT INTO "fourcc" VALUES('FXT1','3dfx Interactive, Inc.','1999-07-27','Not specified.');
INSERT INTO "fourcc" VALUES('GWLT','Microsoft','1994-07-24','Microsoft Greyscale WLT DIB');
INSERT INTO "fourcc" VALUES('H260','ITU-T','1996-06-12','H.260');
INSERT INTO "fourcc" VALUES('H261','ITU-T','1996-06-12','H.261');
INSERT INTO "fourcc" VALUES('H262','ITU-T','1996-06-12','H.262');
INSERT INTO "fourcc" VALUES('H263','ITU-T','1996-06-12','H.263');
INSERT INTO "fourcc" VALUES('H264','ITU-T/ISO/IEC','1996-06-12','H.264/MPEG-4 AVC');
INSERT INTO "fourcc" VALUES('H265',NULL,'1996-06-12','Intel ITU H.265');
INSERT INTO "fourcc" VALUES('H266',NULL,'1996-06-12','Intel ITU H.266');
INSERT INTO "fourcc" VALUES('H267',NULL,'1996-06-12','Intel ITU H.267');
INSERT INTO "fourcc" VALUES('H268',NULL,'1996-06-12','Intel ITU H.268');
INSERT INTO "fourcc" VALUES('H269',NULL,'1996-06-12','Intel ITU H.263 for POTS-based videoconferencing');
INSERT INTO "fourcc" VALUES('I263','ITU-T','1997-09-16','H.263');
INSERT INTO "fourcc" VALUES('I420','*No Decoder Needed','1996-01-15','RAW I420');
INSERT INTO "fourcc" VALUES('IAN ','Intel Corporation','1996-06-12','Intel RDX.');
INSERT INTO "fourcc" VALUES('ICLB','InSoft','1994-05-16','CellB Videoconferencing Codec');
INSERT INTO "fourcc" VALUES('ILVC','Intel','1997-09-16','Layered Video');
INSERT INTO "fourcc" VALUES('ILVR','ITU-T','1997-10-29','H.263');
INSERT INTO "fourcc" VALUES('IMAC','Intel Corporation','1998-07-20','Intel hardware motion compensation.');
INSERT INTO "fourcc" VALUES('IPDV','I-O Data Device, Inc.','1999-06-25','Giga AVI DV Codec');
INSERT INTO "fourcc" VALUES('IYUV','*No codec needed',NULL,'Planar YUV format (8-bpp Y plane, 8-bpp U and V planes)');
INSERT INTO "fourcc" VALUES('JBYR','Kensington',NULL,'Kensington Codec');
INSERT INTO "fourcc" VALUES('JFIF',NULL,NULL,'JPEG File Interchange Format');
INSERT INTO "fourcc" VALUES('JPEG','Microsoft',NULL,'Still Image JPEG DIB');
INSERT INTO "fourcc" VALUES('JPG ',NULL,NULL,'JPEG compressed');
INSERT INTO "fourcc" VALUES('JPGL','http://www.jpg.com/',NULL,'Pegasus Lossless Motion JPEG');
INSERT INTO "fourcc" VALUES('KMVC','Team17 Software',NULL,'Karl Morton''s Video Codec (presumably)');
INSERT INTO "fourcc" VALUES('KPCD','Kodak',NULL,'Kodak Photo CD');
INSERT INTO "fourcc" VALUES('L261','LEAD Multimedia',NULL,'LEAD H.261');
INSERT INTO "fourcc" VALUES('L263','LEAD Multimedia',NULL,'LEAD H.263');
INSERT INTO "fourcc" VALUES('L264','LEAD Multimedia',NULL,'LEAD H.264');
INSERT INTO "fourcc" VALUES('LAGS','Ben Greenwood',NULL,'Lagarith Lossless');
INSERT INTO "fourcc" VALUES('LBYR','Creative Labs, Inc.',NULL,'Creative WebCam');
INSERT INTO "fourcc" VALUES('LCMW','LEAD Multimedia',NULL,'LEAD Motion CMW Codec');
INSERT INTO "fourcc" VALUES('LCW2','LEAD Multimedia',NULL,'LEAD MCMW 9Motion Wavelet');
INSERT INTO "fourcc" VALUES('IRAW','Intel','1996-06-12','Intel YUV Uncompressed');
INSERT INTO "fourcc" VALUES('LGRY','LEAD Multimedia',NULL,'LEAD Grayscale Image');
INSERT INTO "fourcc" VALUES('ISME','Intel Corporation','1998-07-01','Intel''s next-generation video codec.');
INSERT INTO "fourcc" VALUES('LJ2K','LEAD Multimedia',NULL,'LEADTools JPEG2000');
INSERT INTO "fourcc" VALUES('IUYV','http://www.leadtools.com/','2001-08-09','Interlaced version of UYVY');
INSERT INTO "fourcc" VALUES('LMP2','LEAD Multimedia',NULL,'LEADTools MPEG2');
INSERT INTO "fourcc" VALUES('LMRT','Microsoft',NULL,'Liquid Motion Runtime Control');
INSERT INTO "fourcc" VALUES('LOCO',NULL,NULL,'LOCO Lossless Codec');
INSERT INTO "fourcc" VALUES('LSCR',NULL,NULL,'LEAD Screen Capture');
INSERT INTO "fourcc" VALUES('IV30','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV31','Ligos / Indeo / Intel','1993-08-01','Indeo 3.x');
INSERT INTO "fourcc" VALUES('LSVM','ESPRE Solutions',NULL,'Lightning Strike Video Codec');
INSERT INTO "fourcc" VALUES('IV32','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('LSVX','ESPRE Solutions',NULL,'Lightning Strike Video Codec');
INSERT INTO "fourcc" VALUES('LX63','LEAD Multimedia',NULL,'LEAD H263 Codec');
INSERT INTO "fourcc" VALUES('LZO1','oberhumer.com',NULL,'LZO (oberhumer lossless)');
INSERT INTO "fourcc" VALUES('M261','Microsoft',NULL,'H.261');
INSERT INTO "fourcc" VALUES('M263','Microsoft',NULL,'H.263');
INSERT INTO "fourcc" VALUES('M4CC',NULL,NULL,'ESS MPEG4 Divio codec');
INSERT INTO "fourcc" VALUES('MC12','ATI Technologies',NULL,'Motion Compensation Format');
INSERT INTO "fourcc" VALUES('MC24',NULL,NULL,'MainConcept Motion JPEG');
INSERT INTO "fourcc" VALUES('MCAM','ATI Technologies',NULL,'Motion Compensation Format');
INSERT INTO "fourcc" VALUES('MCZM',NULL,NULL,'Theory MicroCosm Lossless 64bit RGB w/alpha');
INSERT INTO "fourcc" VALUES('MDVD','http://www.tiasoft.de/',NULL,'Alex MicroDVD Video (hacked MS MPEG-4)');
INSERT INTO "fourcc" VALUES('MDVF',NULL,NULL,'Pinnacle DV/DV50/DVHD100');
INSERT INTO "fourcc" VALUES('MHFY',NULL,NULL,'A.M.Paredes mhuffyYUV (LossLess)');
INSERT INTO "fourcc" VALUES('MJ2C','http://www.morgan-multimedia.com/',NULL,'Morgan Multimedia JPEG 2000');
INSERT INTO "fourcc" VALUES('MJP2','ISO',NULL,'Motion JPEG 2000');
INSERT INTO "fourcc" VALUES('MJPA','http://www.morgan-multimedia.com',NULL,'Morgan Motion JPEG Codec');
INSERT INTO "fourcc" VALUES('Y211','*No codec needed',NULL,'YUV packed');
INSERT INTO "fourcc" VALUES('MJPB','http://www.morgan-multimedia.com',NULL,'Morgan Motion JPEG Codec');
INSERT INTO "fourcc" VALUES('MJPG',NULL,NULL,'Motion JPEG');
INSERT INTO "fourcc" VALUES('MJPX',NULL,NULL,'Pegasus PICVideo Motion JPEG');
INSERT INTO "fourcc" VALUES('ML20','Logitech/Microsoft',NULL,'Mimic MSN Messenger Webcam');
INSERT INTO "fourcc" VALUES('IV33','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV34','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('MNVD',NULL,NULL,'MindBend MindVid LossLess');
INSERT INTO "fourcc" VALUES('IV35','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV36','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV37','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('MP41','Microsoft',NULL,'Microsoft MPEG-4 V1 (enhanced H263)');
INSERT INTO "fourcc" VALUES('IV38','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV39','Ligos / Indeo / Intel','1996-06-12','Indeo 3.x');
INSERT INTO "fourcc" VALUES('IV40','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV41','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV42','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV43','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV44','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('MPG1',NULL,NULL,'FFmpeg MPEG 1/2');
INSERT INTO "fourcc" VALUES('MPG2',NULL,NULL,'FFmpeg MPEG 1/2');
INSERT INTO "fourcc" VALUES('MPG3','Microsoft',NULL,'MS MPEG-4 v3');
INSERT INTO "fourcc" VALUES('IV45','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('MPGI','Sigma Designs',NULL,'MPEG');
INSERT INTO "fourcc" VALUES('MPNG',NULL,NULL,'PNG images decoder');
INSERT INTO "fourcc" VALUES('IV46','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV47','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV48','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('MSS2','Microsoft',NULL,'Windows Media 9 Screen Video');
INSERT INTO "fourcc" VALUES('MSUC',NULL,NULL,'MSU LossLess');
INSERT INTO "fourcc" VALUES('MSUD',NULL,NULL,'MSU LossLess');
INSERT INTO "fourcc" VALUES('IV49','Ligos / Indeo / Intel','1996-06-12','Indeo 4.x');
INSERT INTO "fourcc" VALUES('IV50','Ligos / Indeo / Intel','1997-09-16','Indeo 5.x');
INSERT INTO "fourcc" VALUES('MSZH','S&K LCL (Lossless Codec Library)',NULL,'avimszh (lossless, ZLIB)');
INSERT INTO "fourcc" VALUES('MTGA',NULL,NULL,'Motion TGA images (24, 32 bpp)');
INSERT INTO "fourcc" VALUES('MTX1','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX2','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX3','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX4','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX5','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX6','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX7','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX8','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('MTX9','Matrox',NULL,'Matrox, possibly a texture format');
INSERT INTO "fourcc" VALUES('IY41','LEAD Multimedia','2001-08-09','Interlaced version of Y41P');
INSERT INTO "fourcc" VALUES('IYU1','IEEE standard','1999-08-17','12 bit format used in mode 2 of the IEEE 1394 1.04 spec');
INSERT INTO "fourcc" VALUES('IYU2','IEEE standard','1999-08-17','24 bit format used in mode 2 of the IEEE 1394 1.04 spec');
INSERT INTO "fourcc" VALUES('LEAD','LEAD Multimedia','2001-08-09','LEAD Video Codec');
INSERT INTO "fourcc" VALUES('LIA1','Liafail, Inc.','2000-06-30','Liafail');
INSERT INTO "fourcc" VALUES('LJPG','LEAD Multimedia','2001-08-09','LEAD MJPEG Codec');
INSERT INTO "fourcc" VALUES('LSV0','Infinop Inc.','1999-08-30','Reserved.');
INSERT INTO "fourcc" VALUES('MVI1',NULL,NULL,'Motion Pixels MVI');
INSERT INTO "fourcc" VALUES('MVI2',NULL,NULL,'Motion Pixels MVI');
INSERT INTO "fourcc" VALUES('MWV1','Aware Inc.',NULL,'Aware Motion Wavelets');
INSERT INTO "fourcc" VALUES('MYUV',NULL,NULL,'Media-100 844/X Uncompressed');
INSERT INTO "fourcc" VALUES('NAVI','IRC #shadowrealm',NULL,'SMR Codec (hack of Microsoft Mpeg-4)');
INSERT INTO "fourcc" VALUES('NDIG',NULL,NULL,'Ahead Nero Digital MPEG-4 Codec');
INSERT INTO "fourcc" VALUES('NHVU',NULL,NULL,'NVidia Texture Format (GEForce 3)');
INSERT INTO "fourcc" VALUES('NO16',NULL,NULL,'Theory None16 64bit uncompressed RAW');
INSERT INTO "fourcc" VALUES('NT00','http://www.newtek.com/',NULL,'NewTek LightWave HDTV YUV with Alpha-channel');
INSERT INTO "fourcc" VALUES('LSVC','ESPRE Solutions','1999-08-30','Lightning Strike Video Codec');
INSERT INTO "fourcc" VALUES('NTN2',NULL,NULL,'Nogatech Video Compression 2 (GrabBee hardware coder)');
INSERT INTO "fourcc" VALUES('NUV1','#NAME?',NULL,'NuppelVideo (RTjpeg2.0)');
INSERT INTO "fourcc" VALUES('NV11','*No Decoder Needed',NULL,'8-bit 4:1:1 YUV');
INSERT INTO "fourcc" VALUES('NV12','*No Decoder Needed',NULL,'8-bit Y plane 2x2 subsampling');
INSERT INTO "fourcc" VALUES('NV21','*No Decoder Needed',NULL,'As NV12 with U and V reversed');
INSERT INTO "fourcc" VALUES('LSVW','Infinop Inc.','1999-08-30','Lightning Strike multi-bitrate');
INSERT INTO "fourcc" VALUES('M101','Matrox Electronic Systems, Ltd.','2002-01-31','Uncompressed field-based YUY2.');
INSERT INTO "fourcc" VALUES('M4S2','Microsoft','2001-04-02','Compliant MPEG-4 v2 Simple Profile');
INSERT INTO "fourcc" VALUES('MMES','Matrox','1999-05-06','Matrox MPEG-2 I-frame');
INSERT INTO "fourcc" VALUES('MMIF','Matrox Electronic Systems, Ltd.','1999-05-11','Matrox MPEG-2 elementary I-frame-only video stream.');
INSERT INTO "fourcc" VALUES('MP2A',NULL,'2001-09-20','Media Excel MPEG-2 Audio');
INSERT INTO "fourcc" VALUES('MP2T',NULL,'2001-09-20','Media Excel MPEG-2 Transport Stream');
INSERT INTO "fourcc" VALUES('MP2V','Microsoft','2001-09-20','S-Mpeg 4 version 1');
INSERT INTO "fourcc" VALUES('MP42','Microsoft','1997-10-28','S-Mpeg 4 version 2');
INSERT INTO "fourcc" VALUES('MP43','Microsoft','1998-04-30','S-Mpeg 4 version 3');
INSERT INTO "fourcc" VALUES('MP4A','~ISOMP4','2001-09-20','MPEG-4 Audio');
INSERT INTO "fourcc" VALUES('MP4S','Microsoft','2001-04-02','ISO MPEG-4 Video V1');
INSERT INTO "fourcc" VALUES('MP4T',NULL,'2001-09-20','Media Excel MPEG-4 Transport Stream');
INSERT INTO "fourcc" VALUES('MP4V','~ISOMP4','2001-09-20','MPEG-4 Video');
INSERT INTO "fourcc" VALUES('MPEG','Chromatic Research','1997-09-16','MPEG-1');
INSERT INTO "fourcc" VALUES('MPG4','Microsoft','2001-04-02','MS MPEG-4 v1');
INSERT INTO "fourcc" VALUES('MRCA','FAST Multimedia','1997-09-16','Mrcodec');
INSERT INTO "fourcc" VALUES('MRLE','Microsoft','1992-11-01','Run Length Encoding');
INSERT INTO "fourcc" VALUES('MSS1','Microsoft','1999-04-02','Windows Media 7 Screen Video');
INSERT INTO "fourcc" VALUES('MSV1','Microsoft','1998-06-05','Microsoft video codec V1.');
INSERT INTO "fourcc" VALUES('MSVC','Microsoft','1992-11-01','Video 1');
INSERT INTO "fourcc" VALUES('MV10','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('MV11','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('MV12','Motion Pixels','1999-01-06','Motion Pixels Codec (old)');
INSERT INTO "fourcc" VALUES('MV99','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('OSIL','LEAD Multimedia',NULL,'LEAD ISO DeMuxer');
INSERT INTO "fourcc" VALUES('PCL2','Pinnacle / Avid',NULL,'Pinnacle RL video codec.');
INSERT INTO "fourcc" VALUES('PDVC','I-O Data Device, Inc.',NULL,'DVC codec');
INSERT INTO "fourcc" VALUES('PGVV','Radius',NULL,'Radius Video Vision');
INSERT INTO "fourcc" VALUES('PHMO','IBM Corporation',NULL,'Photomotion');
INSERT INTO "fourcc" VALUES('PIM1','Pinnacle / Avid',NULL,'MPEG-1 Realtime (Pinnacle Cards)');
INSERT INTO "fourcc" VALUES('PIM2','Pinnacle / Avid',NULL,'MPEG-2 IP (Pinnacle Cards)');
INSERT INTO "fourcc" VALUES('PIMJ','Pegasus Imaging',NULL,'Pegasus Lossless JPEG');
INSERT INTO "fourcc" VALUES('PIXL','Pinnacle / Avid',NULL,'MiroXL, Pinnacle PCTV');
INSERT INTO "fourcc" VALUES('PNG ','Apple',NULL,'Apple PNG');
INSERT INTO "fourcc" VALUES('PNG1',NULL,NULL,'Corecodec.org CorePNG Codec');
INSERT INTO "fourcc" VALUES('PVEZ','Horizons Technology',NULL,'PowerEZ');
INSERT INTO "fourcc" VALUES('PVMM','PacketVideo Corporation',NULL,'PacketVideo Corporation MPEG-4');
INSERT INTO "fourcc" VALUES('PVW2','Pegasus Imaging',NULL,'Pegasus Wavelet 2000 Compression');
INSERT INTO "fourcc" VALUES('PVWV',NULL,NULL,'Pegasus Imaging Wavelet 2000');
INSERT INTO "fourcc" VALUES('PXLT','Apple',NULL,'Apple Pixlet (Wavelet)');
INSERT INTO "fourcc" VALUES('Q1.0','Q-Team Dr Knabe',NULL,'Q-Team''s QPEG (www.q-team.de)');
INSERT INTO "fourcc" VALUES('Q1.1','Q-Team Dr Knabe',NULL,'Q-Team''s QPEG (www.q-team.de)');
INSERT INTO "fourcc" VALUES('QDGX','Apple',NULL,'Apple QuickDraw GX');
INSERT INTO "fourcc" VALUES('QDRW','Apple',NULL,'APPLE Quickdraw Palettized Video');
INSERT INTO "fourcc" VALUES('QPEQ','Q-Team Dr Knabe',NULL,'Q-Team QPEG 1.1');
INSERT INTO "fourcc" VALUES('R210',NULL,NULL,'BlackMagic YUV (Quick Time)');
INSERT INTO "fourcc" VALUES('R411','Radius / Cinepak',NULL,'Radius DV NTSC YUV');
INSERT INTO "fourcc" VALUES('R420','Radius / Cinepak',NULL,'Radius DV PAL YUV');
INSERT INTO "fourcc" VALUES('RASC','LogMeIn, Inc.',NULL,'LogMeIn Screen Codec');
INSERT INTO "fourcc" VALUES('RAV_',NULL,NULL,'GroupTRON ReferenceAVI codec (dummy for MPEG compressor)');
INSERT INTO "fourcc" VALUES('RAVI',NULL,NULL,'GroupTRON ReferenceAVI codec (dummy for MPEG compressor)');
INSERT INTO "fourcc" VALUES('RAW ','*No codec needed',NULL,'Uncompressed RGB');
INSERT INTO "fourcc" VALUES('RGB ','* No codec needed',NULL,'Uncompressed BGR32');
INSERT INTO "fourcc" VALUES('RGB1',NULL,NULL,'Uncompressed RGB332 3:3:2');
INSERT INTO "fourcc" VALUES('RGBA','* No codec needed',NULL,'Raw RGB w/ Alpha');
INSERT INTO "fourcc" VALUES('RGBO',NULL,NULL,'Uncompressed RGB555 5:5:5');
INSERT INTO "fourcc" VALUES('RGBP',NULL,NULL,'Uncompressed RGB565 5:6:5');
INSERT INTO "fourcc" VALUES('RGBQ',NULL,NULL,'Uncompressed RGB555X 5:5:5 BE');
INSERT INTO "fourcc" VALUES('RGBR',NULL,NULL,'Uncompressed RGB565X 5:6:5 BE');
INSERT INTO "fourcc" VALUES('MVC1','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('MVC2','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('RJPG','ffmpeg',NULL,'ffmeg NuppelVideo (RTjpeg2.0)');
INSERT INTO "fourcc" VALUES('RL4 ',NULL,NULL,'RLE 4bpp RGB');
INSERT INTO "fourcc" VALUES('RL8 ',NULL,NULL,'RLE 8bpp RGB');
INSERT INTO "fourcc" VALUES('RLE ','* No codec needed',NULL,'Run Length Encoded');
INSERT INTO "fourcc" VALUES('RLE4','* No codec needed',NULL,'Same as BI_RLE4 (RLE 4bpp RGB)');
INSERT INTO "fourcc" VALUES('RLE8','* No codec needed',NULL,'Same as BI_RLE8 (RLE 8bpp RGB)');
INSERT INTO "fourcc" VALUES('MVC9','Nokia Mobile Phones','1999-01-06','Nokia MVC video codec.');
INSERT INTO "fourcc" VALUES('RMP4','http://www.sigmadesigns.com/',NULL,'REALmagic MPEG-4 (unauthorized XVID copy)');
INSERT INTO "fourcc" VALUES('ROQV','id Software',NULL,'RoQ VideoGame File');
INSERT INTO "fourcc" VALUES('RPZA','Apple',NULL,'Apple RoadPizza');
INSERT INTO "fourcc" VALUES('NTN1','Nogatech','1998-01-06','Video Compression 1');
INSERT INTO "fourcc" VALUES('RTV0',NULL,NULL,'NewTek VideoToaster (dummy format - only AVI header)');
INSERT INTO "fourcc" VALUES('RUD0','http://rududu.ifrance.com/rududu/',NULL,'Rududu video codec');
INSERT INTO "fourcc" VALUES('RV10','RealNetworks',NULL,'RealVideo 1.0');
INSERT INTO "fourcc" VALUES('RV13','RealNetworks',NULL,'RealVideo 1.0 variant');
INSERT INTO "fourcc" VALUES('RV20','RealNetworks',NULL,'RealVideo 2.0');
INSERT INTO "fourcc" VALUES('RV30','RealNetworks',NULL,'RealVideo 3.0');
INSERT INTO "fourcc" VALUES('RV40','RealNetworks',NULL,'RealVideo 4.0');
INSERT INTO "fourcc" VALUES('NVDS',NULL,'2001-09-17','nVidia Texture Format');
INSERT INTO "fourcc" VALUES('NVHS',NULL,'2001-04-02','NVidia Texture Format (GEForce 3)');
INSERT INTO "fourcc" VALUES('S422','Tekram International',NULL,'VideoCap C210');
INSERT INTO "fourcc" VALUES('SAMR','~ISOMP4',NULL,'Narrowband AMR voice');
INSERT INTO "fourcc" VALUES('SAN3',NULL,NULL,'MPEG-4 codec (direct copy of DivX 3.11a)');
INSERT INTO "fourcc" VALUES('SANM','LucasArts',NULL,'LucasArts Smush v2');
INSERT INTO "fourcc" VALUES('SAWB','~ISOMP4',NULL,'Wideband AMR voice');
INSERT INTO "fourcc" VALUES('SAWP','~ISOMP4',NULL,'Extended AMR-WB (AMR-WB+)');
INSERT INTO "fourcc" VALUES('NVHU','NVIDIA Corporation','2001-04-02','Not specified.');
INSERT INTO "fourcc" VALUES('NVS0','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SEDG',NULL,NULL,'Samsung MPEG-4 codec');
INSERT INTO "fourcc" VALUES('SEG4','Sega',NULL,'Cinepak for Sega');
INSERT INTO "fourcc" VALUES('SEGA','Sega',NULL,'Cinepak for Sega');
INSERT INTO "fourcc" VALUES('SEVC','~ISOMP4',NULL,'EVRC Voice (3GPP2)');
INSERT INTO "fourcc" VALUES('NVS1','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SHR0',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR1',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR2',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR3',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR4',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR5',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR6',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SHR7',NULL,NULL,'BitJazz SheerVideo (realtime lossless)');
INSERT INTO "fourcc" VALUES('SJPG',NULL,NULL,'CUseeMe Networks Codec');
INSERT INTO "fourcc" VALUES('SL25',NULL,NULL,'SoftLab-NSK DVCPRO');
INSERT INTO "fourcc" VALUES('SL50',NULL,NULL,'SoftLab-NSK DVCPRO50');
INSERT INTO "fourcc" VALUES('SLDV',NULL,NULL,'SoftLab-NSK Forward DV Draw codec');
INSERT INTO "fourcc" VALUES('SLIF',NULL,NULL,'SoftLab-NSK MPEG2 I-frames');
INSERT INTO "fourcc" VALUES('SLMJ',NULL,NULL,'SoftLab-NSK Forward MJPEG');
INSERT INTO "fourcc" VALUES('SMC ','Apple',NULL,'Apple Graphics');
INSERT INTO "fourcc" VALUES('SMK2','ffmpeg',NULL,'FFmpeg Smacker Video');
INSERT INTO "fourcc" VALUES('SMK4','ffmpeg',NULL,'FFmpeg Smacker Video');
INSERT INTO "fourcc" VALUES('SMP4','Samsung',NULL,'Samsung Camcorder');
INSERT INTO "fourcc" VALUES('NVS2','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('NVS3','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SMSV','WorldConnect',NULL,'Wavelet Video');
INSERT INTO "fourcc" VALUES('SNOW','ffmpeg',NULL,'FFSNOW (Michael''s wavelet codec)');
INSERT INTO "fourcc" VALUES('SP40',NULL,NULL,'SunPlus YUV');
INSERT INTO "fourcc" VALUES('SP44',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP53',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP54','Logitech',NULL,'Sunplus Sp54 Codec for Mustek GSmart Mini 2');
INSERT INTO "fourcc" VALUES('SP55',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP56',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP57',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP58',NULL,NULL,'SunPlus Aiptek MegaCam Codec');
INSERT INTO "fourcc" VALUES('SP61','Sunplus Technology',NULL,'Sunplus Codec for Hama Sightcam');
INSERT INTO "fourcc" VALUES('SPIG','Radius',NULL,'Spigot');
INSERT INTO "fourcc" VALUES('NVS4','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SPRK',NULL,NULL,'Sorenson Spark');
INSERT INTO "fourcc" VALUES('SQCP','~ISOMP4',NULL,'13K Voice (3GPP2)');
INSERT INTO "fourcc" VALUES('NVS5','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SSMV','~ISOMP4',NULL,'SMV Voice (3GPP2)');
INSERT INTO "fourcc" VALUES('NVS6','NVIDIA Corporation','1999-04-29','Not specified.');
INSERT INTO "fourcc" VALUES('NVS7','NVIDIA Corporation','1999-04-29','Not specified.');
INSERT INTO "fourcc" VALUES('NVS8','NVIDIA Corporation','1999-04-29','Not specified.');
INSERT INTO "fourcc" VALUES('STVX','ST Microelectronics',NULL,'ST CMOS Imager Data (Extended CODEC  Format)');
INSERT INTO "fourcc" VALUES('STVY','ST Microelectronics',NULL,'ST CMOS Imager Data (Extended CODEC  Format w/ Correction)');
INSERT INTO "fourcc" VALUES('NVS9','NVIDIA Corporation','1999-04-29','Not specified.');
INSERT INTO "fourcc" VALUES('NVT0','NVIDIA Corporation','1999-04-29','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('SVQ1','Sorenson Media',NULL,'Sorenson v1');
INSERT INTO "fourcc" VALUES('SVQ3','Sorenson Media',NULL,'Sorenson v3 (QT 5)');
INSERT INTO "fourcc" VALUES('SWC1',NULL,NULL,'MainConcept Motion JPEG');
INSERT INTO "fourcc" VALUES('T420','Toshiba',NULL,'Toshiba YUV 4:2:0');
INSERT INTO "fourcc" VALUES('TGA ','Apple',NULL,'Apple TGA w/alpha');
INSERT INTO "fourcc" VALUES('THEO','xiph.org/theora.org  (open source)',NULL,'Theora (free, reworked VP3)');
INSERT INTO "fourcc" VALUES('THRA','xiph.org/theora.org (open source)',NULL,'Theora (free, reworked VP3)');
INSERT INTO "fourcc" VALUES('TIFF','Apple',NULL,'Apple TIFF w/alpha');
INSERT INTO "fourcc" VALUES('TIM2',NULL,NULL,'Pinnacle RAL DVI');
INSERT INTO "fourcc" VALUES('NVT1','NVIDIA Corporation','1999-03-23','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('NVT2','NVIDIA Corporation','1999-03-23','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('TM10','Duck (now ON2) Corp',NULL,'TrueMotion 1.0');
INSERT INTO "fourcc" VALUES('DIV4','DivX','2001-04-02','DivX 3 Fast-Motion');
INSERT INTO "fourcc" VALUES('TM2A','Duck (now ON2) Corporation',NULL,'Duck TrueMotion Archiver 2.0');
INSERT INTO "fourcc" VALUES('TM2X','Duck (now ON2) Corp',NULL,'Duck TrueMotion 2X');
INSERT INTO "fourcc" VALUES('TRLE',NULL,NULL,'Akula Alpha Pro Custom AVI (LossLess)');
INSERT INTO "fourcc" VALUES('TSCC','Techsmith Corp.',NULL,'TechSmith Screen Capture Codec');
INSERT INTO "fourcc" VALUES('TV10','Tecomac, Inc.',NULL,'Tecomac Low-Bit Rate Codec');
INSERT INTO "fourcc" VALUES('TVJP','Pinnacle / Avid',NULL,'Targa 2000 board');
INSERT INTO "fourcc" VALUES('TVMJ','Pinnacle / Avid',NULL,'Targa 2000 board');
INSERT INTO "fourcc" VALUES('TWOS','*No codec needed',NULL,'Uncompressed 16-bit audio');
INSERT INTO "fourcc" VALUES('TY0N','http://www.tecomac.com',NULL,'Tecomac Low-Bit Rate Codec');
INSERT INTO "fourcc" VALUES('Y216',NULL,NULL,'Pinnacle TARGA CineWave YUV (Quick Time)');
INSERT INTO "fourcc" VALUES('TY2C','Trident Microsystems',NULL,'Trident Decompression Driver');
INSERT INTO "fourcc" VALUES('TY2N','Trident Microsystems',NULL,'Trident Codec');
INSERT INTO "fourcc" VALUES('U263','UB Video Inc.',NULL,'UB Video H.263/H.263+/H.263++ Decoder');
INSERT INTO "fourcc" VALUES('U<Y ',NULL,NULL,'Discreet UC YUV 4:2:2:4 10 bit');
INSERT INTO "fourcc" VALUES('U<YA',NULL,NULL,'Discreet UC YUV 4:2:2:4 10 bit (with Alpha-channel)');
INSERT INTO "fourcc" VALUES('UCOD','eMajix.com',NULL,'ClearVideo');
INSERT INTO "fourcc" VALUES('ULTI','IBM Corporation',NULL,'Ultimotion');
INSERT INTO "fourcc" VALUES('UMP4','http://www.ubvideo.com',NULL,'UB Video MPEG 4');
INSERT INTO "fourcc" VALUES('UYNV','NVIDIA Corporation',NULL,'Same as UYVY');
INSERT INTO "fourcc" VALUES('NVT3','NVIDIA Corporation','1999-03-23','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('UYVU',NULL,NULL,'SoftLab-NSK Forward YUV codec');
INSERT INTO "fourcc" VALUES('UYVY','*No codec needed',NULL,'UYVY (packed 4:2:2)');
INSERT INTO "fourcc" VALUES('V210',NULL,NULL,'Optibase VideoPump 10-bit 4:2:2 Component Y''CbCr');
INSERT INTO "fourcc" VALUES('V261','Lucent','1999-02-17','Lucent VX2000S');
INSERT INTO "fourcc" VALUES('NVT4','NVIDIA Corporation','1999-03-23','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('NVT5','NVIDIA Corporation','1999-03-23','Nvidia, probably a texture format');
INSERT INTO "fourcc" VALUES('VBLE',NULL,NULL,'MarcFD VBLE Lossless Codec');
INSERT INTO "fourcc" VALUES('NVT6','NVIDIA Corporation','1999-03-23','Not specified.');
INSERT INTO "fourcc" VALUES('NVT7','NVIDIA Corporation','1999-03-23','Not specified.');
INSERT INTO "fourcc" VALUES('NVT8','NVIDIA Corporation','1999-03-23','Not specified.');
INSERT INTO "fourcc" VALUES('NVT9','NVIDIA Corporation','1999-03-23','Not specified.');
INSERT INTO "fourcc" VALUES('NY12','Nogatech Ltd.','1999-06-28','Nogatech YUV 12 format.');
INSERT INTO "fourcc" VALUES('AEMI','Array Microsystems','1998-09-14','Array VideoONE MPEG1-I Capture');
INSERT INTO "fourcc" VALUES('ALPH','Ziracom Digital Communications Inc.','2001-04-24','Not specified.');
INSERT INTO "fourcc" VALUES('Y411','*No codec needed',NULL,'Same as Y41P');
INSERT INTO "fourcc" VALUES('Y41B','Weitek',NULL,'YUV 4:1:1 Planar');
INSERT INTO "fourcc" VALUES('VCRD','Open Source',NULL,'Dirac Video Codec');
INSERT INTO "fourcc" VALUES('Y41P','*No codec needed',NULL,'YUV 4:1:1 Packed');
INSERT INTO "fourcc" VALUES('VDCT','Vitec Multimedia',NULL,'Video Maker Pro DIB');
INSERT INTO "fourcc" VALUES('VDOM','VDONet',NULL,'VDOWave');
INSERT INTO "fourcc" VALUES('VDOW','VDONet',NULL,'VDOLive');
INSERT INTO "fourcc" VALUES('VDST',NULL,NULL,'VirtualDub remote frameclient ICM driver');
INSERT INTO "fourcc" VALUES('VDTZ','Darim Vision Co.',NULL,'VideoTizer YUV Codec');
INSERT INTO "fourcc" VALUES('Y41T','Brooktree Corporation',NULL,'PC1 4:1:1 with transparency');
INSERT INTO "fourcc" VALUES('VIDM',NULL,NULL,'DivX 5.0 Pro Supported Codec');
INSERT INTO "fourcc" VALUES('VIDS','Vitec Multimedia',NULL,'YUV 4:2:2 CCIR 601 for V422');
INSERT INTO "fourcc" VALUES('VIFP','http://www.yks.ne.jp/~hori/',NULL,'VFAPI Reader Codec');
INSERT INTO "fourcc" VALUES('VIV1',NULL,NULL,'FFmpeg H263+ decoder');
INSERT INTO "fourcc" VALUES('VIV2','Vivo Software',NULL,'Vivo H.263');
INSERT INTO "fourcc" VALUES('Y422','ADS Technologies',NULL,'Copy of UYVY used in Pyro WebCam firewire camera');
INSERT INTO "fourcc" VALUES('Y42B','Weitek USA',NULL,'YUV 4:2:2 Planar');
INSERT INTO "fourcc" VALUES('Y42T','Brooktree Corporation',NULL,'UYVY with pixel transparency support');
INSERT INTO "fourcc" VALUES('Y444',NULL,NULL,'IYU2 (iRez Stealth Fire camera)');
INSERT INTO "fourcc" VALUES('VMNC','VMware',NULL,'VMware Codec');
INSERT INTO "fourcc" VALUES('VP30','On2 Technologies',NULL,'On2 VP3');
INSERT INTO "fourcc" VALUES('VP31','On2 Technologies',NULL,'On2 VP3');
INSERT INTO "fourcc" VALUES('VP40','On2 Technologies',NULL,'On2 VP4');
INSERT INTO "fourcc" VALUES('VP50','On2 Technologies',NULL,'On2 VP5');
INSERT INTO "fourcc" VALUES('VP60','On2 Technologies',NULL,'On2 VP6 / Flash');
INSERT INTO "fourcc" VALUES('VP61','On2 Technologies',NULL,'On2 VP6 / Flash');
INSERT INTO "fourcc" VALUES('VP62','On2 Technologies',NULL,'On2 VP6 / Flash');
INSERT INTO "fourcc" VALUES('VP6F','ffmpeg (open source)',NULL,'FFmpeg VP6 / Flash');
INSERT INTO "fourcc" VALUES('VP70','On2 Technologies',NULL,'On2 VP7');
INSERT INTO "fourcc" VALUES('VP71','On2 Technologies',NULL,'On2 VP7');
INSERT INTO "fourcc" VALUES('VP72','On2 Technologies',NULL,'On2 VP7');
INSERT INTO "fourcc" VALUES('Y8  ','* No codec needed',NULL,'Grayscale video');
INSERT INTO "fourcc" VALUES('Y800','* No codec needed',NULL,'Grayscale video');
INSERT INTO "fourcc" VALUES('YMPG',NULL,NULL,'YMPEG Alpha (dummy for MPEG-2 compressor)');
INSERT INTO "fourcc" VALUES('YU12','ATI Technologies',NULL,'ATI YV12 4:2:0 Planar');
INSERT INTO "fourcc" VALUES('VR21',NULL,NULL,'BlackMagic YUV (Quick Time)');
INSERT INTO "fourcc" VALUES('VRBS','ffmpeg',NULL,'FFmpeg Vorbis decoder');
INSERT INTO "fourcc" VALUES('VSSH','Videosoft, http://www.videosoftinc.com/',NULL,'Videosoft H.264 Codec 2');
INSERT INTO "fourcc" VALUES('VSSV',NULL,NULL,'Vanguard Software Solutions Video Codec');
INSERT INTO "fourcc" VALUES('VSSW',NULL,NULL,'Vanguard VSS H.264');
INSERT INTO "fourcc" VALUES('YU92','Intel Corporation',NULL,'YUV');
INSERT INTO "fourcc" VALUES('YUNV','NVIDIA Corporation',NULL,'Same as YUY2');
INSERT INTO "fourcc" VALUES('YUV2','Apple',NULL,'Apple YUV 4:2:2');
INSERT INTO "fourcc" VALUES('YUVP','http://www.riff.org',NULL,'Extended PAL format YUV palette');
INSERT INTO "fourcc" VALUES('YUY2','*No codec needed',NULL,'YUV packed 4:2:2');
INSERT INTO "fourcc" VALUES('YV12','*No codec needed',NULL,'IYUV w/ U & V switched');
INSERT INTO "fourcc" VALUES('YV16',NULL,NULL,'Elecard YUV 4:2:2 Planar');
INSERT INTO "fourcc" VALUES('YV92',NULL,NULL,'Intel''s Smart Video Recorder YVU9');
INSERT INTO "fourcc" VALUES('YVU9','*No codec needed',NULL,'Planar YUV format');
INSERT INTO "fourcc" VALUES('VTLP',NULL,NULL,'Alaris VideoGramPiX');
INSERT INTO "fourcc" VALUES('YVYU','*No codec needed',NULL,'YUV packed 4:2:2');
INSERT INTO "fourcc" VALUES('ZLIB','S&K LCL (Lossless Codec Library)',NULL,'avizlib (lossless, ZLIB/PNG)');
INSERT INTO "fourcc" VALUES('ZMBV','Konstantin Shishkov',NULL,'Zip Motion Blocks Video');
INSERT INTO "fourcc" VALUES('VYU9','ATI Technologies',NULL,'ATI YUV');
INSERT INTO "fourcc" VALUES('VYUY','ATI Technologies',NULL,'ATI YUV');
INSERT INTO "fourcc" VALUES('WAKE',NULL,NULL,'Unknown MJPG Variant');
INSERT INTO "fourcc" VALUES('ZYGO',NULL,NULL,'ZyGo Video Codec');
INSERT INTO "fourcc" VALUES('WHAM','Microsoft',NULL,'Microsoft Video 1');
INSERT INTO "fourcc" VALUES('AMPG','Array Microsystems','1998-07-09','Array VideoONE MPEG');
INSERT INTO "fourcc" VALUES('ANIM','Intel','1996-06-12','Intel RDX');
INSERT INTO "fourcc" VALUES('AP41','AngelPotion','2001-04-02','AngelPotion Definitive');
INSERT INTO "fourcc" VALUES('AUR2','AuraVision Corporation','1994-01-04','AuraVision Aura 2: YUV 422');
INSERT INTO "fourcc" VALUES('AURA','AuraVision Corporation','1994-01-04','AuraVision Aura 1: YUV 411');
INSERT INTO "fourcc" VALUES('AUVX','USH GmbH','2002-03-15','AUVX video codec.');
INSERT INTO "fourcc" VALUES('WMVA','Microsoft',NULL,'WMP v10 (VC-1 Beta)');
INSERT INTO "fourcc" VALUES('WMVP','Microsoft',NULL,'WMP v9 Image');
INSERT INTO "fourcc" VALUES('WMVR','Microsoft',NULL,'WMV Unknown');
INSERT INTO "fourcc" VALUES('WNIX',NULL,NULL,'WniWni Codec');
INSERT INTO "fourcc" VALUES('BT20','Conexant','1995-06-05','Prosumer Video');
INSERT INTO "fourcc" VALUES('WNVA',NULL,NULL,'Winnov hw compress');
INSERT INTO "fourcc" VALUES('BTCV','Conexant','1995-06-05','Composite Video Codec');
INSERT INTO "fourcc" VALUES('WRLE','Apple',NULL,'Apple RLE BMP');
INSERT INTO "fourcc" VALUES('WRPR',NULL,NULL,'VideoTools VideoServer Client (wrapper for AviSynth)');
INSERT INTO "fourcc" VALUES('WV1F',NULL,NULL,'WV1F (MPEG-4 variation)');
INSERT INTO "fourcc" VALUES('WVC1','Microsoft',NULL,'VC-1 Adv (WMP11)');
INSERT INTO "fourcc" VALUES('WVLT',NULL,NULL,'IllusionHope Wavelet 9/7');
INSERT INTO "fourcc" VALUES('WVP2','Microsoft',NULL,'Windows Media Video 9.1 Image v2');
INSERT INTO "fourcc" VALUES('CC12','Intel','1996-06-12','YUV12 Codec');
INSERT INTO "fourcc" VALUES('CDVC','Canopus','1997-11-21','Canopus DV Codec');
INSERT INTO "fourcc" VALUES('X263','Xirlink',NULL,'Xirlink');
INSERT INTO "fourcc" VALUES('X264',NULL,NULL,'XiWave GNU GPL x264 MPEG-4 Codec');
INSERT INTO "fourcc" VALUES('CGDI','Microsoft','2001-09-10','Camcorder Video');
INSERT INTO "fourcc" VALUES('CHAM','Winnov, Inc.','1993-09-05','MM_WINNOV_CAVIARA_CHAMPAGNE');
INSERT INTO "fourcc" VALUES('XMPG','XING Corporation',NULL,'XING MPEG');
INSERT INTO "fourcc" VALUES('XVID','xvid.org (open source)',NULL,'XviD ISO MPEG-4');
INSERT INTO "fourcc" VALUES('XVIX',NULL,NULL,'Based on XviD MPEG-4 codec');
INSERT INTO "fourcc" VALUES('CM10','CyberLink Corporation','2000-08-21','MediaShow 1.0.');
INSERT INTO "fourcc" VALUES('CPLA','Weitek','1994-07-18','YUV 4:2:0');
INSERT INTO "fourcc" VALUES('CT10','CyberLink Corporation','2000-08-21','TalkingShow 1.0.');
INSERT INTO "fourcc" VALUES('CVID','Supermac','1993-08-01','Cinepak by Supermac');
INSERT INTO "fourcc" VALUES('CWLT','Microsoft','1994-07-24','Microsoft Color WLT DIB');
INSERT INTO "fourcc" VALUES('DIV3','DivX','2001-04-02','DivX 3 Low-Motion');
INSERT INTO "fourcc" VALUES('XXAN','Origin Systems',NULL,'OSI Game Codec');
INSERT INTO "fourcc" VALUES('XYZP','http://www.riff.org',NULL,'Extended PAL format XYZ palette');
INSERT INTO "fourcc" VALUES('DIVX','Project Mayo','2000-12-12','DivX 4 (OpenDivX)');
INSERT INTO "fourcc" VALUES('DJPG','Data Translation, Inc.','1998-07-27','Broadway 101 Motion JPEG codec.');
INSERT INTO "fourcc" VALUES('DP16','Matsushita','1998-05-19','YUV411 with DPCM 6-bit compression.');
INSERT INTO "fourcc" VALUES('DP18','Matsushita','1998-05-19','YUV411 with DPCM 8-bit compression.');
INSERT INTO "fourcc" VALUES('DP26','Matsushita','1998-05-19','YUV422 with DPCM 6-bit compression.');
INSERT INTO "fourcc" VALUES('DP28','Matsushita','1998-05-19','YUV422 with DPCM 8-bit compression.');
INSERT INTO "fourcc" VALUES('DP96','Matsushita','1998-05-19','YVU9 with DPCM 6-bit compression.');
INSERT INTO "fourcc" VALUES('DP98','Matsushita','1998-05-19','YVU9 with DPCM 8-bit compression.');
INSERT INTO "fourcc" VALUES('DP9L','Matsushita','1998-05-19','YVU9 with DPCM 6-bit compression and thinned-out.');
INSERT INTO "fourcc" VALUES('DUCK','Duck Corporation','1997-09-16','TrueMotion S');
INSERT INTO "fourcc" VALUES('DVE2','InSoft','1994-05-16','DVE-2 Videoconferencing Codec');
INSERT INTO "fourcc" VALUES('DVH1',NULL,'2002-11-13','Pinnacle DVHD100');
INSERT INTO "fourcc" VALUES('DVNM','Matsushita','2001-02-14','Not specified.');
INSERT INTO "fourcc" VALUES('DVX1','Lucent','1999-02-17','DVX1000SP Video Decoder');
INSERT INTO "fourcc" VALUES('DVX2','Lucent','1999-02-17','DVX2000S Video Decoder');
INSERT INTO "fourcc" VALUES('DVX3','Lucent','1999-02-17','DVX3000S Video Decoder');
INSERT INTO "fourcc" VALUES('DXT0','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXT1','Microsoft','1998-02-25','DirectX Texture Compression Format 1');
INSERT INTO "fourcc" VALUES('DXT2','Microsoft','1998-02-25','DirectX Texture Compression Format 2');
INSERT INTO "fourcc" VALUES('DXT3','Microsoft','1998-02-25','DirectX Texture Compression Format 3');
INSERT INTO "fourcc" VALUES('DXT4','Microsoft','1998-02-25','DirectX Texture Compression Format 4');
INSERT INTO "fourcc" VALUES('DXT5','Microsoft','1998-02-25','DirectX Texture Compression Format 5');
INSERT INTO "fourcc" VALUES('DXT6','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXT7','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXT8','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXT9','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTA','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTB','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTC','Microsoft','1998-01-27','DirectX Texture Compression');
INSERT INTO "fourcc" VALUES('DXTD','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTE','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTF','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTG','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTH','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTI','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTJ','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTK','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTL','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTM','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTN','Microsoft','1998-02-25','DirectX Compressed Texture');
INSERT INTO "fourcc" VALUES('DXTO','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTP','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTQ','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTR','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTS','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTT','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTU','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTV','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTW','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTX','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTY','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('DXTZ','Microsoft','1998-02-25','Reserved.');
INSERT INTO "fourcc" VALUES('EMWC','EverAd, Inc.','2001-01-12','EverAd Marquee WMA codec.');
INSERT INTO "fourcc" VALUES('ETV1','eTreppid Technologies','2001-10-11','eTreppid Video Codec');
INSERT INTO "fourcc" VALUES('ETV2','eTreppid Technologies','2001-10-11','eTreppid Video Codec');
INSERT INTO "fourcc" VALUES('ETVC','eTreppid Technologies','2001-10-11','eTreppid Video Codec');
INSERT INTO "fourcc" VALUES('FLJP','D-Vision','1996-10-21','Field Encoded Motion JPEG');
INSERT INTO "fourcc" VALUES('FRWA','SoftLab-Nsk','1998-06-25','Forward Motion JPEG w/alpha');
CREATE UNIQUE INDEX idx_fourcc ON fourcc (fourcc);
COMMIT;
